# pygame-utility


## Official Documentation
[pygame_utility](https://pygame-utility.readthedocs.io/en/latest/index.html)

**Note: This package is currently under development. Features and documentation may change as updates are made.**

`pygame-utility` is a package that contains simple utility modules for Pygame.

## Features

- Utility functions for image loading and processing.
- Utility class for loading map from tiled map editor.
- Sorting utilities for managing file names with numeric parts. Images are sorted numerically based on any numeric values in their filenames, rather than lexicographically.

## Installation

You can install the package via pip:

```bash
pip install pygame-utility

